# Coscine Python Client

![Coscine](data/logo.png)

[Coscine](https://coscine.rwth-aachen.de/) is an integration platform for
research data hosted at RWTH Aachen University. For more information visit
the [Landing Page](https://coscine.de/).

## About

This python3.x library provides a simple interface to Coscine. You can use it
to integrate Coscine in your python applications and easily:
- create or delete projects and resources
- invite and manage project members
- upload and download files, resources or even whole projects
- manage your metadata

Even if you plan on using the API directly in a programming language of your choice,
you might want to take a look at this module as it provides you with a handy
debug mode which logs all requests and responses made in the communication with coscine.
This makes it simple to understand how certain workflows should be implemented or why
something in your implementation might not work.

## Documentation

Documentation and installation instructions can be found [here](https://git.rwth-aachen.de/coscine/docs/public/coscine-api-python-client/-/wikis/home).

## Contact

To report bugs, request features or resolve questions open an issue inside
of the current git repository.

To contribute code and help improve this package fork the repository and
open a merge request.

For general help or consulting contact RWTH Aachen
IT ServiceDesk at <servicedesk@rwth-aachen.de>.

## License

This project is Open Source Software and licensed
under the terms of the MIT License.
```
The MIT License (MIT)
Copyright © 2021 RWTH Aachen University

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
the Software, and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
```
